@@ -1,4 +1,5 @@
-from typing import Generator, List, Union
+from typing import Generator, List, Optional, Union
+
 
 try:
     import stanza
@@ -19,6 +20,7 @@ except ImportError:
     SPACY_AVAILABLE = False
 
 if SPACY_AVAILABLE:
+
     class SpacyPretokenizedTokenizer:
         """Custom tokenizer to be used in spaCy when the text is already pretokenized."""
 
@@ -44,7 +46,6 @@ if SPACY_AVAILABLE:
                     "Unexpected input format. Expected string to be split on whitespace, or list of tokens."
                 )
 
-
     @SpacyLanguage.component("prevent_sbd")
     def spacy_prevent_sbd(doc: SpacyDoc):
         """Disables spaCy's sentence boundary detection."""
@@ -90,13 +91,21 @@ def pair_combs(all_pairs: List, min_length: int = 2) -> Generator[List, None, No
     n_pairs = len(all_pairs)
     for i in range(n_pairs, min_length - 1, -1):
         for j in range(n_pairs - i + 1):
-            pairs = all_pairs[j: j + i]
+            pairs = all_pairs[j : j + i]
             if any(item.is_null for pair in pairs for item in pair):
                 continue
             yield pairs
 
 
-def load_parser(model_or_lang, parser=None, *, is_tokenized=True, use_gpu=True, **kwargs):
+def load_parser(
+    model_or_lang: str,
+    parser: Optional[str] = None,
+    *,
+    auto_download: bool = True,
+    is_tokenized: bool = True,
+    use_gpu: bool = True,
+    **kwargs,
+):
     try:
         if parser == "spacy":
             if use_gpu:
@@ -113,18 +122,21 @@ def load_parser(model_or_lang, parser=None, *, is_tokenized=True, use_gpu=True,
             else:
                 nlp = spacy.load(model_or_lang, **kwargs)
         elif parser == "stanza":
-            stanza.download(model_or_lang)
+            if auto_download:
+                stanza.download(model_or_lang, verbose=False)
             nlp = StanzaPipeline(
                 processors="tokenize,pos,lemma,depparse",
                 lang=model_or_lang,
                 tokenize_pretokenized=is_tokenized,
                 use_gpu=use_gpu,
                 logging_level="WARNING",
-                **kwargs
+                **kwargs,
             )
         else:
             if STANZA_AVAILABLE:
-                return load_parser(model_or_lang, parser="stanza", is_tokenized=is_tokenized, use_gpu=use_gpu, **kwargs)
+                return load_parser(
+                    model_or_lang, parser="stanza", is_tokenized=is_tokenized, use_gpu=use_gpu, **kwargs
+                )
             elif SPACY_AVAILABLE:
                 return load_parser(model_or_lang, parser="spacy", is_tokenized=is_tokenized, use_gpu=use_gpu, **kwargs)
             else:
@@ -140,6 +152,7 @@ def load_parser(model_or_lang, parser=None, *, is_tokenized=True, use_gpu=True,
 try:
     from functools import cached_property
 except (ImportError, AttributeError):
+
     class cached_property(property):
         """
         Descriptor that mimics @property but caches output in member variable.
@@ -159,5 +172,3 @@ except (ImportError, AttributeError):
                 cached = self.fget(obj)
                 setattr(obj, attr, cached)
             return cached
-
-
